AppDropDown<T> class

Inheritance

Constructors

AppDropDown.multiSelect({Key? key, bool isMultiDropDown = true, String? title, required List<T> list, required List<T>? multiSelectedValue, required dynamic multiValueBuilder(T)?, required dynamic itemBuilder(T), required dynamic onMultiChange(List<T>)?, dynamic onSingleChange(T)?, T? selectedValue, dynamic singleValueBuilder(T)?, String? hint, bool isFilled = false, Color? borderColor, double? radius, EdgeInsets? padding, EdgeInsets? boxPadding, double? menuMaxHeight, double? width, Widget? textBox, dynamic onCreateController(MenuController)?, String? error, bool isEnabled = true, dynamic onTap()?, Widget? prefixIcon, Widget? suffixIcon})
const
AppDropDown.singleSelect({Key? key, String? title, bool isMultiDropDown = false, required List<T> list, required T? selectedValue, required dynamic singleValueBuilder(T)?, required dynamic itemBuilder(T), required dynamic onSingleChange(T)?, dynamic onMultiChange(List<T>)?, dynamic multiValueBuilder(T)?, List<T>? multiSelectedValue, String? hint, bool isFilled = false, Color? borderColor, double? radius, EdgeInsets? padding, EdgeInsets? boxPadding, double? menuMaxHeight, double? width, Widget? textBox, dynamic onCreateController(MenuController)?, String? error, bool isEnabled = true, dynamic onTap()?, Widget? prefixIcon, Widget? suffixIcon})
const

Properties

borderColor Color?
final
boxPadding EdgeInsets?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
isEnabled bool
final
isFilled bool
final
isMultiDropDown bool
final
itemBuilder → dynamic Function(T)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
list List<T>
final
final
multiSelectedValue List<T>?
final
multiValueBuilder → dynamic Function(T)?
final
onCreateController → dynamic Function(MenuController)?
final
onMultiChange → dynamic Function(List<T>)?
final
onSingleChange → dynamic Function(T)?
final
onTap → dynamic Function()?
final
padding EdgeInsets?
final
prefixIcon Widget?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedValue → T?
final
singleValueBuilder → dynamic Function(T)?
final
suffixIcon Widget?
final
textBox Widget?
final
title String?
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
generateValue() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited