PlatformInfo class

Constructors

PlatformInfo()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

context BuildContext?
no setter
firstView FlutterView
final
height double
no setter
isDesktop bool
no setter
isLargeTab bool
no setter
isPhone bool
no setter
isSmallTab bool
no setter
isTab bool
no setter