AppColors class

Constructors

AppColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bgcolor → const Color
black → const Color
blackText → const Color
border → const Color
bottomBarColor → const Color
btnColor → const Color
cardBaground → const Color
cardbagroundColor → const Color
cardBagroundHome → const Color
cardColor → const Color
colorF5 → const Color
containerBackground → const Color
containerBorderColor → const Color
contcolor → const Color
divider → const Color
editTextField → const Color
exploreColorColor → const Color
forgetText → const Color
gradientBtn → const LinearGradient
gradientBtnGrey → const LinearGradient
green → const Color
greenlight → const Color
Grey → const Color
grey → const Color
greyHint → const Color
greynew → const Color
greySetting → const Color
homeCard → const LinearGradient
messageSample → const Color
messageUser → const Color
newgrey → const Color
orange → const Color
primaryBlue → const Color
primaryColor → const Color
profileCard → const LinearGradient
quzeYellow → const Color
red → const Color
resultcolor → const Color
retake → const Color
scorecolor → const Color
searchFieldColor → const Color
splashColor → const Color
termAndCondation → const Color
termandcondation → const Color
transp → const Color
trofColor → const Color
txtfieldtext → const Color
white → const Color
yellow → const Color