AppImages class

Constructors

AppImages()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

ageIcon → const String
appImage → const String
appleIcon → const String
backBtn → const String
cameraaa → const String
dummyImg → const String
googleIcon → const String
privacyIcon → const String
shuffleImg → const String
splashImg → const String
videoicon → const String