EditTextTheme class

Constructors

EditTextTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

disableBorder InputBorder
no setter
editTextTheme InputDecorationTheme
no setter
enabledBorder InputBorder
no setter
errorBorder InputBorder
no setter
focusedBorder InputBorder
no setter
outlinedBorder BorderSide
no setter
setBorder InputBorder
no setter
setErrorBorder InputBorder
no setter