AppStrings class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ageVerification → const String
- confirmYouAreOver18YearsOfAge → const String
- continueWithApple → const String
- continueWithGoogle → const String
- Iam18OrOlderEnter → const String
- IamUnder18 → const String
- readyForTodayChallenge → const String
- userId → const String
- vag → const String
- verifyAndContinue → const String
- yourAgeInfo → const String
- yourPrivacyIsProtected → const String