SliderCustomThumbShape class

Inheritance

Constructors

SliderCustomThumbShape({double thumbRadius = 10.0})
const

Properties

disabledThumbRadius double?
The preferred radius of the round thumb shape when the slider is disabled.
finalinherited
elevation double
The resting elevation adds shadow to the unpressed thumb.
finalinherited
enabledThumbRadius double
The preferred radius of the round thumb shape when the slider is enabled.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
pressedElevation double
The pressed elevation adds shadow to the pressed thumb.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbRadius double
final

Methods

getPreferredSize(bool isEnabled, bool isDiscrete) Size
Returns the preferred size of the shape, based on the given conditions.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset center, {Animation<double>? activationAnimation, Animation<double>? enableAnimation, bool? isDiscrete, TextPainter? labelPainter, RenderBox? parentBox, required SliderThemeData sliderTheme, TextDirection? textDirection, double? value, double? textScaleFactor, Size? sizeWithOverflow}) → void
Paints the shape, taking into account the state passed to it.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited