UiTheme class

Inheritance
Annotations

Constructors

UiTheme({required Color appBarColor, required Color appBarSecondaryColor, required Color appBarDataColor, required Color appBarSecondaryDataColor, required Color backGroundColor, required Color backGroundSecondaryColor, required Color splashColor, required Color editTextField, required Color forgetText, required Color cardColor, required Color btnColor, required Color grey, required Color transp, required Color colorF5, required Color cardBaground, required Color cardbagroundColor, required Color red, required Color yellow, required Color exploreColorColor, required Color bgcolor, required Color green, required Color termandcondation, required Color orange, required Color primaryBlue, required Color greyHint, required Color retake, required Color border, required Color divider, required Color greynew, required Color greySetting, required Color contcolor, required Color greenlight, required Color newgrey, required Color resultcolor, required Color txtfieldtext, required Color blackText, required Color white})
const

Properties

appBarColor Color
final
appBarDataColor Color
final
appBarSecondaryColor Color
final
appBarSecondaryDataColor Color
final
backGroundColor Color
final
backGroundSecondaryColor Color
final
bgcolor Color
final
blackText Color
final
border Color
final
btnColor Color
final
cardBaground Color
final
cardbagroundColor Color
final
cardColor Color
final
colorF5 Color
final
contcolor Color
final
divider Color
final
editTextField Color
final
exploreColorColor Color
final
forgetText Color
final
green Color
final
greenlight Color
final
grey Color
final
greyHint Color
final
greynew Color
final
greySetting Color
final
hashCode int
The hash code for this object.
no setterinherited
newgrey Color
final
orange Color
final
primaryBlue Color
final
red Color
final
resultcolor Color
final
retake Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color
final
termandcondation Color
final
transp Color
final
txtfieldtext Color
final
type Object
The extension's type.
no setterinherited
white Color
final
yellow Color
final

Methods

copyWith({Color? appBarColor, Color? appBarSecondaryColor, Color? appBarDataColor, Color? appBarSecondaryDataColor, Color? backGroundColor, Color? backGroundSecondaryColor, Color? splashColor, Color? editTextField, Color? forgetText, Color? cardColor, Color? btnColor, Color? grey, Color? transp, Color? colorF5, Color? cardBaground, Color? cardbagroundColor, Color? red, Color? yellow, Color? exploreColorColor, Color? bgcolor, Color? green, Color? termandcondation, Color? orange, Color? primaryBlue, Color? greyHint, Color? retake, Color? border, Color? divider, Color? greynew, Color? greySetting, Color? contcolor, Color? greenlight, Color? newgrey, Color? resultcolor, Color? txtfieldtext, Color? blackText, Color? white}) UiTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UiTheme>? other, double t) UiTheme
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited