ApiUtils class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
call({Map<String, dynamic>? responseStatusValue, required Future<Response> request, required Map<String, dynamic> data(Map<String, dynamic>), dynamic error(ResponseData)?})
→ Future<ResponseData<Map<String, dynamic>>>
-
-
deleteMethod({required Uri url, Map<String, String>? query})
→ Future<Response>
-
-
generateResponse<T>(T data)
→ ResponseData<T>
-
-
generateUri(String url, Map<String, String>? query)
→ Uri
-
-
getMethod({required Uri url, Map<String, dynamic>? body})
→ Future<Response>
-
-
-
patchMethod({required Uri url, Map<String, dynamic>? body, Map<String, String>? multipartFile})
→ Future<Response>
-
-
postMethod({required Uri url, Map<String, dynamic>? body, Map<String, String>? multipartFile})
→ Future<Response>
-
-
putMethod({required Uri url, Map<String, dynamic>? body, Map<String, String>? multipartFile})
→ Future<Response>
-