AppDecoration class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
appBarDecoration(
{Color? color, bool hasShadow = true}) → BoxDecoration -
bDecorationGreyR(
{double radius = 10, double borderWidth = 2, Color? borderColor}) → BoxDecoration -
bDecorationPBlue(
{double radius = 10, double borderWidth = 2, Color? color}) → BoxDecoration -
bDecorationWhiteShadow(
{double radius = 10, double borderWidth = 2, Color? color}) → BoxDecoration -
inputBorder(
{double? radius, Color? borderColor}) → InputBorder