AppUtils class
Constructors
- AppUtils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- deviceType → String
-
no setter
- userId → dynamic
-
Getter for the user ID
no setter
Static Methods
-
fetchVideoBytes(
String videoUrl) → Future< Uint8List?> -
imagePicker(
) → Future< String?> -
launchInBrowser(
String url) → Future< void> -
log(
dynamic msg) → void - Logs a debug message
-
logEr(
dynamic msg) → void - Logs an error message
-
setUserId(
dynamic id) → void - Sets the user ID dynamically
-
toast(
String msg) → void -
toastError(
dynamic error) → void -
videoPicker(
) → Future< String?>